==> connectagram_1.2.1.orig.tar.bz2: connectagram-1.2.1/translations/connectagram_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>ChainPattern</name>
    <message>
        <location filename="../src/pattern.h" line="145"/>
        <source>Chain</source>
        <translation>Grandinė</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <location filename="../src/clock.cpp" line="70"/>
        <source>Loading</source>
        <translation>Įkeliama</translation>
    </message>
    <message>
        <location filename="../src/clock.cpp" line="112"/>
        <source>Paused</source>
        <translation>Pauzė</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <location filename="../src/definitions.cpp" line="36"/>
        <source>Definitions</source>
        <translation>Apibrėžtys</translation>
    </message>
    <message>
        <location filename="../src/definitions.cpp" line="145"/>
        <source>Downloading definition...</source>
        <translation>Atsiunčiama apibrėžtis...</translation>
    </message>
    <message>
        <location filename="../src/definitions.cpp" line="153"/>
        <source>Unsolved word</source>
        <translation>Neįmintas žodis</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <location filename="../src/dictionary.cpp" line="133"/>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Apibrėžtis iš Vikižodyno, laisvojo žodyno</translation>
    </message>
    <message>
        <location filename="../src/dictionary.cpp" line="140"/>
        <source>No definition found</source>
        <translation>Apibrėžtis nerasta</translation>
    </message>
    <message>
        <location filename="../src/dictionary.cpp" line="143"/>
        <source>Unable to connect to Wiktionary</source>
        <translation>Neįmanoma prisijungti prie Vikižodyno</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <location filename="../src/pattern.h" line="170"/>
        <source>Fence</source>
        <translation>Tvora</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="52"/>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalbą:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="55"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos Kalba&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="173"/>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="173"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="44"/>
        <source>New Game</source>
        <translation>Naujas Žaidimas</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="57"/>
        <location filename="../src/window.cpp" line="278"/>
        <source>Low</source>
        <translation>Mažas</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="57"/>
        <location filename="../src/window.cpp" line="279"/>
        <source>Medium</source>
        <translation>Vidutinis</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="57"/>
        <location filename="../src/window.cpp" line="280"/>
        <source>High</source>
        <translation>Didelis</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="57"/>
        <location filename="../src/window.cpp" line="281"/>
        <source>Very High</source>
        <translation>Labai Didelis</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="92"/>
        <location filename="../src/window.cpp" line="292"/>
        <source>Language:</source>
        <translation>Kalba:</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="94"/>
        <location filename="../src/window.cpp" line="294"/>
        <source>Word Length:</source>
        <translation>Žodžių Ilgis:</translation>
    </message>
    <message>
        <location filename="../src/new_game_dialog.cpp" line="93"/>
        <location filename="../src/window.cpp" line="293"/>
        <source>Amount of Words:</source>
        <translation>Žodžių Kiekis:</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/new_game_dialog.cpp" line="142"/>
        <location filename="../src/window.cpp" line="294"/>
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n raidė</numerusform>
            <numerusform>%n raidės</numerusform>
            <numerusform>%n raidžių</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <location filename="../src/pattern.h" line="195"/>
        <source>Rings</source>
        <translation>Žiedai</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <location filename="../src/score_board.cpp" line="33"/>
        <source>Scores</source>
        <translation>Surinkti Taškai</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Score</source>
        <translation>Surinkta Taškų</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Time</source>
        <translation>Laikas</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Words</source>
        <translation>Žodžiai</translation>
    </message>
    <message>
        <location filename="../src/score_board.cpp" line="37"/>
        <source>Length</source>
        <translation>Ilgis</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <location filename="../src/pattern.h" line="216"/>
        <source>Stairs</source>
        <translation>Laiptai</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <location filename="../src/pattern.h" line="233"/>
        <source>Twisty</source>
        <translation>Vingiuota</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <location filename="../src/pattern.h" line="256"/>
        <source>Wave</source>
        <translation>Banga</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="70"/>
        <location filename="../src/window.cpp" line="85"/>
        <source>Success</source>
        <translation>Sėkmė</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="97"/>
        <source>Loading</source>
        <translation>Įkeliama</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="97"/>
        <source>Paused</source>
        <translation>Pauzė</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="122"/>
        <source>Definitions</source>
        <translation>Apibrėžtys</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="128"/>
        <source>Hint</source>
        <translation>Patarimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="159"/>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="160"/>
        <source>&amp;New</source>
        <translation>Na&amp;ujas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="161"/>
        <source>&amp;Choose...</source>
        <translation>Pasi&amp;rinkti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="170"/>
        <source>&amp;Details</source>
        <translation>&amp;Išsamiau</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="163"/>
        <location filename="../src/window.cpp" line="338"/>
        <source>&amp;Pause</source>
        <translation>Pau&amp;zė</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="163"/>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <source>&amp;Hint</source>
        <translation>&amp;Patarimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="165"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="168"/>
        <source>D&amp;efinitions</source>
        <translation>&amp;Apibrėžtys</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="168"/>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <source>&amp;Scores</source>
        <translation>&amp;Surinkti Taškai</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <source>&amp;Quit</source>
        <translation>&amp;Baigti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="176"/>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="177"/>
        <source>Application &amp;Language...</source>
        <translation>Programos &amp;Kalba</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="179"/>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="180"/>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="182"/>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="217"/>
        <source>Choose Game</source>
        <translation>Pasirinkite Žaidimą</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="217"/>
        <location filename="../src/window.cpp" line="295"/>
        <source>Game Number:</source>
        <translation>Žaidimo Numeris:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="221"/>
        <source>Sorry</source>
        <translation>Atleiskite</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="221"/>
        <source>Unable to start requested game.</source>
        <translation>Neįmanoma pradėti užklausto žaidimo.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="261"/>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="30"/>
        <location filename="../src/window.cpp" line="262"/>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="263"/>
        <source>A word unscrambling game</source>
        <translation>Žodžių iššifravimo žaidimas</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="264"/>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Autorinės Teisės &amp;copy; 2009-%1 by Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="265"/>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="266"/>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Apibrėžtys yra iš &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Vikižodyno&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="289"/>
        <source>Details</source>
        <translation>Išsamiau</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="291"/>
        <source>Pattern:</source>
        <translation>Šablonas:</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="338"/>
        <source>&amp;Resume</source>
        <translation>P&amp;ratęsti</translation>
    </message>
</context>
</TS>

==> connectagram-1.3.8.tar.bz2: connectagram-1.3.8/translations/connectagram_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Grandinė</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Įkeliama</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pauzė</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Tvora</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Pasirinkite programos kalbą:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistemos kalba&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Pastaba</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Kad įsigaliotų kalbos pakeitimai, prašome paleisti programą iš naujo.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Naujas žaidimas</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Mažas</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Vidutinis</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Didelis</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Labai didelis</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Kalba:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Žodžių ilgis:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Žodžių kiekis:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n raidė</numerusform>
            <numerusform>%n raidės</numerusform>
            <numerusform>%n raidžių</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Žiedai</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Rekordai</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation>Rangas</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Vardas</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Surinkta taškų</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Laikas</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Žodžiai</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Ilgis</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Sveikiname!</translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation>Jūs sumušėte savo rekordą!</translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation>Puikiai padirbėta!</translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation>Jūs pasiekėte naują rekordą!</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Laiptai</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Vingiuota</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Banga</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Sėkmė</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Įkeliama</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pauzė</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Apibrėžtys</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Užuomina</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>Žai&amp;dimas</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Na&amp;ujas</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>Pasi&amp;rinkti</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Išsamiau</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>Pau&amp;zė</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Užuomina</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>&amp;Apibrėžtys</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Rekordai</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Baigti</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation>&amp;Tamsi veiksena</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Programos &amp;kalba</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pagalba</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Apie &amp;Qt</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Pasirinkite žaidimą</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Žaidimo numeris:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Atleiskite</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Neįmanoma pradėti užklausto žaidimo.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>Connectagram</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Žodžių iššifravimo žaidimas</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Autorių Teisės &amp;copy; 2009-%1 pagal Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Išleista pagal &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; licenciją</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Apibrėžtys yra iš &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Vikižodyno&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Išsamiau</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Šablonas:</translation>
    </message>
</context>
</TS>
